from pathlib import Path

from setuptools import setup, find_packages

from mypy_boto3.version import __version__ as version


ROOT_PATH = Path(__file__).absolute().parent

long_description = (ROOT_PATH / "README.md").read_text()

setup(
    name="mypy-boto3",
    version=version,
    packages=find_packages(),
    url="https://github.com/vemel/mypy_boto3",
    license="MIT License",
    author="Vlad Emelianov",
    author_email="vlad.emelianov.nz@gmail.com",
    description="Mypy-friendly boto3 type annotations master module.",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Environment :: Console",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: Implementation :: CPython",
        "Typing :: Typed",
    ],
    long_description=long_description,
    long_description_content_type="text/markdown",
    package_data={"mypy_boto3": ["py.typed"]},
    extras_require={
        "all": [
            "mypy-boto3-acm==0.1.7",
            "mypy-boto3-acm-pca==0.1.7",
            "mypy-boto3-alexaforbusiness==0.1.7",
            "mypy-boto3-amplify==0.1.7",
            "mypy-boto3-apigateway==0.1.7",
            "mypy-boto3-apigatewaymanagementapi==0.1.7",
            "mypy-boto3-apigatewayv2==0.1.7",
            "mypy-boto3-application-autoscaling==0.1.7",
            "mypy-boto3-application-insights==0.1.7",
            "mypy-boto3-appmesh==0.1.7",
            "mypy-boto3-appstream==0.1.7",
            "mypy-boto3-appsync==0.1.7",
            "mypy-boto3-athena==0.1.7",
            "mypy-boto3-autoscaling==0.1.7",
            "mypy-boto3-autoscaling-plans==0.1.7",
            "mypy-boto3-backup==0.1.7",
            "mypy-boto3-batch==0.1.7",
            "mypy-boto3-budgets==0.1.7",
            "mypy-boto3-ce==0.1.7",
            "mypy-boto3-chime==0.1.7",
            "mypy-boto3-cloud9==0.1.7",
            "mypy-boto3-clouddirectory==0.1.7",
            "mypy-boto3-cloudformation==0.1.7",
            "mypy-boto3-cloudfront==0.1.7",
            "mypy-boto3-cloudhsm==0.1.7",
            "mypy-boto3-cloudhsmv2==0.1.7",
            "mypy-boto3-cloudsearch==0.1.7",
            "mypy-boto3-cloudsearchdomain==0.1.7",
            "mypy-boto3-cloudtrail==0.1.7",
            "mypy-boto3-cloudwatch==0.1.7",
            "mypy-boto3-codebuild==0.1.7",
            "mypy-boto3-codecommit==0.1.7",
            "mypy-boto3-codedeploy==0.1.7",
            "mypy-boto3-codepipeline==0.1.7",
            "mypy-boto3-codestar==0.1.7",
            "mypy-boto3-codestar-notifications==0.1.7",
            "mypy-boto3-cognito-identity==0.1.7",
            "mypy-boto3-cognito-idp==0.1.7",
            "mypy-boto3-cognito-sync==0.1.7",
            "mypy-boto3-comprehend==0.1.7",
            "mypy-boto3-comprehendmedical==0.1.7",
            "mypy-boto3-config==0.1.7",
            "mypy-boto3-connect==0.1.7",
            "mypy-boto3-cur==0.1.7",
            "mypy-boto3-datapipeline==0.1.7",
            "mypy-boto3-datasync==0.1.7",
            "mypy-boto3-dax==0.1.7",
            "mypy-boto3-devicefarm==0.1.7",
            "mypy-boto3-directconnect==0.1.7",
            "mypy-boto3-discovery==0.1.7",
            "mypy-boto3-dlm==0.1.7",
            "mypy-boto3-dms==0.1.7",
            "mypy-boto3-docdb==0.1.7",
            "mypy-boto3-ds==0.1.7",
            "mypy-boto3-dynamodb==0.1.7",
            "mypy-boto3-dynamodbstreams==0.1.7",
            "mypy-boto3-ec2==0.1.7",
            "mypy-boto3-ec2-instance-connect==0.1.7",
            "mypy-boto3-ecr==0.1.7",
            "mypy-boto3-ecs==0.1.7",
            "mypy-boto3-efs==0.1.7",
            "mypy-boto3-eks==0.1.7",
            "mypy-boto3-elasticache==0.1.7",
            "mypy-boto3-elasticbeanstalk==0.1.7",
            "mypy-boto3-elastictranscoder==0.1.7",
            "mypy-boto3-elb==0.1.7",
            "mypy-boto3-elbv2==0.1.7",
            "mypy-boto3-emr==0.1.7",
            "mypy-boto3-es==0.1.7",
            "mypy-boto3-events==0.1.7",
            "mypy-boto3-firehose==0.1.7",
            "mypy-boto3-fms==0.1.7",
            "mypy-boto3-forecast==0.1.7",
            "mypy-boto3-forecastquery==0.1.7",
            "mypy-boto3-fsx==0.1.7",
            "mypy-boto3-gamelift==0.1.7",
            "mypy-boto3-glacier==0.1.7",
            "mypy-boto3-globalaccelerator==0.1.7",
            "mypy-boto3-glue==0.1.7",
            "mypy-boto3-greengrass==0.1.7",
            "mypy-boto3-groundstation==0.1.7",
            "mypy-boto3-guardduty==0.1.7",
            "mypy-boto3-health==0.1.7",
            "mypy-boto3-iam==0.1.7",
            "mypy-boto3-importexport==0.1.7",
            "mypy-boto3-inspector==0.1.7",
            "mypy-boto3-iot==0.1.7",
            "mypy-boto3-iot-data==0.1.7",
            "mypy-boto3-iot-jobs-data==0.1.7",
            "mypy-boto3-iot1click-devices==0.1.7",
            "mypy-boto3-iot1click-projects==0.1.7",
            "mypy-boto3-iotanalytics==0.1.7",
            "mypy-boto3-iotevents==0.1.7",
            "mypy-boto3-iotevents-data==0.1.7",
            "mypy-boto3-iotthingsgraph==0.1.7",
            "mypy-boto3-kafka==0.1.7",
            "mypy-boto3-kinesis==0.1.7",
            "mypy-boto3-kinesis-video-archived-media==0.1.7",
            "mypy-boto3-kinesis-video-media==0.1.7",
            "mypy-boto3-kinesisanalytics==0.1.7",
            "mypy-boto3-kinesisanalyticsv2==0.1.7",
            "mypy-boto3-kinesisvideo==0.1.7",
            "mypy-boto3-kms==0.1.7",
            "mypy-boto3-lakeformation==0.1.7",
            "mypy-boto3-lambda==0.1.7",
            "mypy-boto3-lex-models==0.1.7",
            "mypy-boto3-lex-runtime==0.1.7",
            "mypy-boto3-license-manager==0.1.7",
            "mypy-boto3-lightsail==0.1.7",
            "mypy-boto3-logs==0.1.7",
            "mypy-boto3-machinelearning==0.1.7",
            "mypy-boto3-macie==0.1.7",
            "mypy-boto3-managedblockchain==0.1.7",
            "mypy-boto3-marketplace-entitlement==0.1.7",
            "mypy-boto3-marketplacecommerceanalytics==0.1.7",
            "mypy-boto3-mediaconnect==0.1.7",
            "mypy-boto3-mediaconvert==0.1.7",
            "mypy-boto3-medialive==0.1.7",
            "mypy-boto3-mediapackage==0.1.7",
            "mypy-boto3-mediapackage-vod==0.1.7",
            "mypy-boto3-mediastore==0.1.7",
            "mypy-boto3-mediastore-data==0.1.7",
            "mypy-boto3-mediatailor==0.1.7",
            "mypy-boto3-meteringmarketplace==0.1.7",
            "mypy-boto3-mgh==0.1.7",
            "mypy-boto3-mobile==0.1.7",
            "mypy-boto3-mq==0.1.7",
            "mypy-boto3-mturk==0.1.7",
            "mypy-boto3-neptune==0.1.7",
            "mypy-boto3-opsworks==0.1.7",
            "mypy-boto3-opsworkscm==0.1.7",
            "mypy-boto3-organizations==0.1.7",
            "mypy-boto3-personalize==0.1.7",
            "mypy-boto3-personalize-events==0.1.7",
            "mypy-boto3-personalize-runtime==0.1.7",
            "mypy-boto3-pi==0.1.7",
            "mypy-boto3-pinpoint==0.1.7",
            "mypy-boto3-pinpoint-email==0.1.7",
            "mypy-boto3-pinpoint-sms-voice==0.1.7",
            "mypy-boto3-polly==0.1.7",
            "mypy-boto3-pricing==0.1.7",
            "mypy-boto3-qldb==0.1.7",
            "mypy-boto3-qldb-session==0.1.7",
            "mypy-boto3-quicksight==0.1.7",
            "mypy-boto3-ram==0.1.7",
            "mypy-boto3-rds==0.1.7",
            "mypy-boto3-rds-data==0.1.7",
            "mypy-boto3-redshift==0.1.7",
            "mypy-boto3-rekognition==0.1.7",
            "mypy-boto3-resource-groups==0.1.7",
            "mypy-boto3-resourcegroupstaggingapi==0.1.7",
            "mypy-boto3-robomaker==0.1.7",
            "mypy-boto3-route53==0.1.7",
            "mypy-boto3-route53domains==0.1.7",
            "mypy-boto3-route53resolver==0.1.7",
            "mypy-boto3-s3==0.1.7",
            "mypy-boto3-s3control==0.1.7",
            "mypy-boto3-sagemaker==0.1.7",
            "mypy-boto3-sagemaker-runtime==0.1.7",
            "mypy-boto3-savingsplans==0.1.7",
            "mypy-boto3-sdb==0.1.7",
            "mypy-boto3-secretsmanager==0.1.7",
            "mypy-boto3-securityhub==0.1.7",
            "mypy-boto3-serverlessrepo==0.1.7",
            "mypy-boto3-service-quotas==0.1.7",
            "mypy-boto3-servicecatalog==0.1.7",
            "mypy-boto3-servicediscovery==0.1.7",
            "mypy-boto3-ses==0.1.7",
            "mypy-boto3-shield==0.1.7",
            "mypy-boto3-signer==0.1.7",
            "mypy-boto3-sms==0.1.7",
            "mypy-boto3-sms-voice==0.1.7",
            "mypy-boto3-snowball==0.1.7",
            "mypy-boto3-sns==0.1.7",
            "mypy-boto3-sqs==0.1.7",
            "mypy-boto3-ssm==0.1.7",
            "mypy-boto3-stepfunctions==0.1.7",
            "mypy-boto3-storagegateway==0.1.7",
            "mypy-boto3-sts==0.1.7",
            "mypy-boto3-support==0.1.7",
            "mypy-boto3-swf==0.1.7",
            "mypy-boto3-textract==0.1.7",
            "mypy-boto3-transcribe==0.1.7",
            "mypy-boto3-transfer==0.1.7",
            "mypy-boto3-translate==0.1.7",
            "mypy-boto3-waf==0.1.7",
            "mypy-boto3-waf-regional==0.1.7",
            "mypy-boto3-workdocs==0.1.7",
            "mypy-boto3-worklink==0.1.7",
            "mypy-boto3-workmail==0.1.7",
            "mypy-boto3-workmailmessageflow==0.1.7",
            "mypy-boto3-workspaces==0.1.7",
            "mypy-boto3-xray==0.1.7",
        ],
        "all-with-docs": [
            "mypy-boto3-acm-with-docs==0.1.7",
            "mypy-boto3-acm-pca-with-docs==0.1.7",
            "mypy-boto3-alexaforbusiness-with-docs==0.1.7",
            "mypy-boto3-amplify-with-docs==0.1.7",
            "mypy-boto3-apigateway-with-docs==0.1.7",
            "mypy-boto3-apigatewaymanagementapi-with-docs==0.1.7",
            "mypy-boto3-apigatewayv2-with-docs==0.1.7",
            "mypy-boto3-application-autoscaling-with-docs==0.1.7",
            "mypy-boto3-application-insights-with-docs==0.1.7",
            "mypy-boto3-appmesh-with-docs==0.1.7",
            "mypy-boto3-appstream-with-docs==0.1.7",
            "mypy-boto3-appsync-with-docs==0.1.7",
            "mypy-boto3-athena-with-docs==0.1.7",
            "mypy-boto3-autoscaling-with-docs==0.1.7",
            "mypy-boto3-autoscaling-plans-with-docs==0.1.7",
            "mypy-boto3-backup-with-docs==0.1.7",
            "mypy-boto3-batch-with-docs==0.1.7",
            "mypy-boto3-budgets-with-docs==0.1.7",
            "mypy-boto3-ce-with-docs==0.1.7",
            "mypy-boto3-chime-with-docs==0.1.7",
            "mypy-boto3-cloud9-with-docs==0.1.7",
            "mypy-boto3-clouddirectory-with-docs==0.1.7",
            "mypy-boto3-cloudformation-with-docs==0.1.7",
            "mypy-boto3-cloudfront-with-docs==0.1.7",
            "mypy-boto3-cloudhsm-with-docs==0.1.7",
            "mypy-boto3-cloudhsmv2-with-docs==0.1.7",
            "mypy-boto3-cloudsearch-with-docs==0.1.7",
            "mypy-boto3-cloudsearchdomain-with-docs==0.1.7",
            "mypy-boto3-cloudtrail-with-docs==0.1.7",
            "mypy-boto3-cloudwatch-with-docs==0.1.7",
            "mypy-boto3-codebuild-with-docs==0.1.7",
            "mypy-boto3-codecommit-with-docs==0.1.7",
            "mypy-boto3-codedeploy-with-docs==0.1.7",
            "mypy-boto3-codepipeline-with-docs==0.1.7",
            "mypy-boto3-codestar-with-docs==0.1.7",
            "mypy-boto3-codestar-notifications-with-docs==0.1.7",
            "mypy-boto3-cognito-identity-with-docs==0.1.7",
            "mypy-boto3-cognito-idp-with-docs==0.1.7",
            "mypy-boto3-cognito-sync-with-docs==0.1.7",
            "mypy-boto3-comprehend-with-docs==0.1.7",
            "mypy-boto3-comprehendmedical-with-docs==0.1.7",
            "mypy-boto3-config-with-docs==0.1.7",
            "mypy-boto3-connect-with-docs==0.1.7",
            "mypy-boto3-cur-with-docs==0.1.7",
            "mypy-boto3-datapipeline-with-docs==0.1.7",
            "mypy-boto3-datasync-with-docs==0.1.7",
            "mypy-boto3-dax-with-docs==0.1.7",
            "mypy-boto3-devicefarm-with-docs==0.1.7",
            "mypy-boto3-directconnect-with-docs==0.1.7",
            "mypy-boto3-discovery-with-docs==0.1.7",
            "mypy-boto3-dlm-with-docs==0.1.7",
            "mypy-boto3-dms-with-docs==0.1.7",
            "mypy-boto3-docdb-with-docs==0.1.7",
            "mypy-boto3-ds-with-docs==0.1.7",
            "mypy-boto3-dynamodb-with-docs==0.1.7",
            "mypy-boto3-dynamodbstreams-with-docs==0.1.7",
            "mypy-boto3-ec2-with-docs==0.1.7",
            "mypy-boto3-ec2-instance-connect-with-docs==0.1.7",
            "mypy-boto3-ecr-with-docs==0.1.7",
            "mypy-boto3-ecs-with-docs==0.1.7",
            "mypy-boto3-efs-with-docs==0.1.7",
            "mypy-boto3-eks-with-docs==0.1.7",
            "mypy-boto3-elasticache-with-docs==0.1.7",
            "mypy-boto3-elasticbeanstalk-with-docs==0.1.7",
            "mypy-boto3-elastictranscoder-with-docs==0.1.7",
            "mypy-boto3-elb-with-docs==0.1.7",
            "mypy-boto3-elbv2-with-docs==0.1.7",
            "mypy-boto3-emr-with-docs==0.1.7",
            "mypy-boto3-es-with-docs==0.1.7",
            "mypy-boto3-events-with-docs==0.1.7",
            "mypy-boto3-firehose-with-docs==0.1.7",
            "mypy-boto3-fms-with-docs==0.1.7",
            "mypy-boto3-forecast-with-docs==0.1.7",
            "mypy-boto3-forecastquery-with-docs==0.1.7",
            "mypy-boto3-fsx-with-docs==0.1.7",
            "mypy-boto3-gamelift-with-docs==0.1.7",
            "mypy-boto3-glacier-with-docs==0.1.7",
            "mypy-boto3-globalaccelerator-with-docs==0.1.7",
            "mypy-boto3-glue-with-docs==0.1.7",
            "mypy-boto3-greengrass-with-docs==0.1.7",
            "mypy-boto3-groundstation-with-docs==0.1.7",
            "mypy-boto3-guardduty-with-docs==0.1.7",
            "mypy-boto3-health-with-docs==0.1.7",
            "mypy-boto3-iam-with-docs==0.1.7",
            "mypy-boto3-importexport-with-docs==0.1.7",
            "mypy-boto3-inspector-with-docs==0.1.7",
            "mypy-boto3-iot-with-docs==0.1.7",
            "mypy-boto3-iot-data-with-docs==0.1.7",
            "mypy-boto3-iot-jobs-data-with-docs==0.1.7",
            "mypy-boto3-iot1click-devices-with-docs==0.1.7",
            "mypy-boto3-iot1click-projects-with-docs==0.1.7",
            "mypy-boto3-iotanalytics-with-docs==0.1.7",
            "mypy-boto3-iotevents-with-docs==0.1.7",
            "mypy-boto3-iotevents-data-with-docs==0.1.7",
            "mypy-boto3-iotthingsgraph-with-docs==0.1.7",
            "mypy-boto3-kafka-with-docs==0.1.7",
            "mypy-boto3-kinesis-with-docs==0.1.7",
            "mypy-boto3-kinesis-video-archived-media-with-docs==0.1.7",
            "mypy-boto3-kinesis-video-media-with-docs==0.1.7",
            "mypy-boto3-kinesisanalytics-with-docs==0.1.7",
            "mypy-boto3-kinesisanalyticsv2-with-docs==0.1.7",
            "mypy-boto3-kinesisvideo-with-docs==0.1.7",
            "mypy-boto3-kms-with-docs==0.1.7",
            "mypy-boto3-lakeformation-with-docs==0.1.7",
            "mypy-boto3-lambda-with-docs==0.1.7",
            "mypy-boto3-lex-models-with-docs==0.1.7",
            "mypy-boto3-lex-runtime-with-docs==0.1.7",
            "mypy-boto3-license-manager-with-docs==0.1.7",
            "mypy-boto3-lightsail-with-docs==0.1.7",
            "mypy-boto3-logs-with-docs==0.1.7",
            "mypy-boto3-machinelearning-with-docs==0.1.7",
            "mypy-boto3-macie-with-docs==0.1.7",
            "mypy-boto3-managedblockchain-with-docs==0.1.7",
            "mypy-boto3-marketplace-entitlement-with-docs==0.1.7",
            "mypy-boto3-marketplacecommerceanalytics-with-docs==0.1.7",
            "mypy-boto3-mediaconnect-with-docs==0.1.7",
            "mypy-boto3-mediaconvert-with-docs==0.1.7",
            "mypy-boto3-medialive-with-docs==0.1.7",
            "mypy-boto3-mediapackage-with-docs==0.1.7",
            "mypy-boto3-mediapackage-vod-with-docs==0.1.7",
            "mypy-boto3-mediastore-with-docs==0.1.7",
            "mypy-boto3-mediastore-data-with-docs==0.1.7",
            "mypy-boto3-mediatailor-with-docs==0.1.7",
            "mypy-boto3-meteringmarketplace-with-docs==0.1.7",
            "mypy-boto3-mgh-with-docs==0.1.7",
            "mypy-boto3-mobile-with-docs==0.1.7",
            "mypy-boto3-mq-with-docs==0.1.7",
            "mypy-boto3-mturk-with-docs==0.1.7",
            "mypy-boto3-neptune-with-docs==0.1.7",
            "mypy-boto3-opsworks-with-docs==0.1.7",
            "mypy-boto3-opsworkscm-with-docs==0.1.7",
            "mypy-boto3-organizations-with-docs==0.1.7",
            "mypy-boto3-personalize-with-docs==0.1.7",
            "mypy-boto3-personalize-events-with-docs==0.1.7",
            "mypy-boto3-personalize-runtime-with-docs==0.1.7",
            "mypy-boto3-pi-with-docs==0.1.7",
            "mypy-boto3-pinpoint-with-docs==0.1.7",
            "mypy-boto3-pinpoint-email-with-docs==0.1.7",
            "mypy-boto3-pinpoint-sms-voice-with-docs==0.1.7",
            "mypy-boto3-polly-with-docs==0.1.7",
            "mypy-boto3-pricing-with-docs==0.1.7",
            "mypy-boto3-qldb-with-docs==0.1.7",
            "mypy-boto3-qldb-session-with-docs==0.1.7",
            "mypy-boto3-quicksight-with-docs==0.1.7",
            "mypy-boto3-ram-with-docs==0.1.7",
            "mypy-boto3-rds-with-docs==0.1.7",
            "mypy-boto3-rds-data-with-docs==0.1.7",
            "mypy-boto3-redshift-with-docs==0.1.7",
            "mypy-boto3-rekognition-with-docs==0.1.7",
            "mypy-boto3-resource-groups-with-docs==0.1.7",
            "mypy-boto3-resourcegroupstaggingapi-with-docs==0.1.7",
            "mypy-boto3-robomaker-with-docs==0.1.7",
            "mypy-boto3-route53-with-docs==0.1.7",
            "mypy-boto3-route53domains-with-docs==0.1.7",
            "mypy-boto3-route53resolver-with-docs==0.1.7",
            "mypy-boto3-s3-with-docs==0.1.7",
            "mypy-boto3-s3control-with-docs==0.1.7",
            "mypy-boto3-sagemaker-with-docs==0.1.7",
            "mypy-boto3-sagemaker-runtime-with-docs==0.1.7",
            "mypy-boto3-savingsplans-with-docs==0.1.7",
            "mypy-boto3-sdb-with-docs==0.1.7",
            "mypy-boto3-secretsmanager-with-docs==0.1.7",
            "mypy-boto3-securityhub-with-docs==0.1.7",
            "mypy-boto3-serverlessrepo-with-docs==0.1.7",
            "mypy-boto3-service-quotas-with-docs==0.1.7",
            "mypy-boto3-servicecatalog-with-docs==0.1.7",
            "mypy-boto3-servicediscovery-with-docs==0.1.7",
            "mypy-boto3-ses-with-docs==0.1.7",
            "mypy-boto3-shield-with-docs==0.1.7",
            "mypy-boto3-signer-with-docs==0.1.7",
            "mypy-boto3-sms-with-docs==0.1.7",
            "mypy-boto3-sms-voice-with-docs==0.1.7",
            "mypy-boto3-snowball-with-docs==0.1.7",
            "mypy-boto3-sns-with-docs==0.1.7",
            "mypy-boto3-sqs-with-docs==0.1.7",
            "mypy-boto3-ssm-with-docs==0.1.7",
            "mypy-boto3-stepfunctions-with-docs==0.1.7",
            "mypy-boto3-storagegateway-with-docs==0.1.7",
            "mypy-boto3-sts-with-docs==0.1.7",
            "mypy-boto3-support-with-docs==0.1.7",
            "mypy-boto3-swf-with-docs==0.1.7",
            "mypy-boto3-textract-with-docs==0.1.7",
            "mypy-boto3-transcribe-with-docs==0.1.7",
            "mypy-boto3-transfer-with-docs==0.1.7",
            "mypy-boto3-translate-with-docs==0.1.7",
            "mypy-boto3-waf-with-docs==0.1.7",
            "mypy-boto3-waf-regional-with-docs==0.1.7",
            "mypy-boto3-workdocs-with-docs==0.1.7",
            "mypy-boto3-worklink-with-docs==0.1.7",
            "mypy-boto3-workmail-with-docs==0.1.7",
            "mypy-boto3-workmailmessageflow-with-docs==0.1.7",
            "mypy-boto3-workspaces-with-docs==0.1.7",
            "mypy-boto3-xray-with-docs==0.1.7",
        ],
        "essential": [
            "mypy-boto3-cloudformation==0.1.7",
            "mypy-boto3-ec2==0.1.7",
            "mypy-boto3-lambda==0.1.7",
            "mypy-boto3-rds==0.1.7",
            "mypy-boto3-s3==0.1.7",
            "mypy-boto3-sqs==0.1.7",
        ],
        "essential-with-docs": [],
        "acm": ["mypy-boto3-acm==0.1.7"],
        "acm-with-docs": ["mypy-boto3-acm-with-docs==0.1.7"],
        "acm-pca": ["mypy-boto3-acm-pca==0.1.7"],
        "acm-pca-with-docs": ["mypy-boto3-acm-pca-with-docs==0.1.7"],
        "alexaforbusiness": ["mypy-boto3-alexaforbusiness==0.1.7"],
        "alexaforbusiness-with-docs": ["mypy-boto3-alexaforbusiness-with-docs==0.1.7"],
        "amplify": ["mypy-boto3-amplify==0.1.7"],
        "amplify-with-docs": ["mypy-boto3-amplify-with-docs==0.1.7"],
        "apigateway": ["mypy-boto3-apigateway==0.1.7"],
        "apigateway-with-docs": ["mypy-boto3-apigateway-with-docs==0.1.7"],
        "apigatewaymanagementapi": ["mypy-boto3-apigatewaymanagementapi==0.1.7"],
        "apigatewaymanagementapi-with-docs": [
            "mypy-boto3-apigatewaymanagementapi-with-docs==0.1.7"
        ],
        "apigatewayv2": ["mypy-boto3-apigatewayv2==0.1.7"],
        "apigatewayv2-with-docs": ["mypy-boto3-apigatewayv2-with-docs==0.1.7"],
        "application-autoscaling": ["mypy-boto3-application-autoscaling==0.1.7"],
        "application-autoscaling-with-docs": [
            "mypy-boto3-application-autoscaling-with-docs==0.1.7"
        ],
        "application-insights": ["mypy-boto3-application-insights==0.1.7"],
        "application-insights-with-docs": [
            "mypy-boto3-application-insights-with-docs==0.1.7"
        ],
        "appmesh": ["mypy-boto3-appmesh==0.1.7"],
        "appmesh-with-docs": ["mypy-boto3-appmesh-with-docs==0.1.7"],
        "appstream": ["mypy-boto3-appstream==0.1.7"],
        "appstream-with-docs": ["mypy-boto3-appstream-with-docs==0.1.7"],
        "appsync": ["mypy-boto3-appsync==0.1.7"],
        "appsync-with-docs": ["mypy-boto3-appsync-with-docs==0.1.7"],
        "athena": ["mypy-boto3-athena==0.1.7"],
        "athena-with-docs": ["mypy-boto3-athena-with-docs==0.1.7"],
        "autoscaling": ["mypy-boto3-autoscaling==0.1.7"],
        "autoscaling-with-docs": ["mypy-boto3-autoscaling-with-docs==0.1.7"],
        "autoscaling-plans": ["mypy-boto3-autoscaling-plans==0.1.7"],
        "autoscaling-plans-with-docs": [
            "mypy-boto3-autoscaling-plans-with-docs==0.1.7"
        ],
        "backup": ["mypy-boto3-backup==0.1.7"],
        "backup-with-docs": ["mypy-boto3-backup-with-docs==0.1.7"],
        "batch": ["mypy-boto3-batch==0.1.7"],
        "batch-with-docs": ["mypy-boto3-batch-with-docs==0.1.7"],
        "budgets": ["mypy-boto3-budgets==0.1.7"],
        "budgets-with-docs": ["mypy-boto3-budgets-with-docs==0.1.7"],
        "ce": ["mypy-boto3-ce==0.1.7"],
        "ce-with-docs": ["mypy-boto3-ce-with-docs==0.1.7"],
        "chime": ["mypy-boto3-chime==0.1.7"],
        "chime-with-docs": ["mypy-boto3-chime-with-docs==0.1.7"],
        "cloud9": ["mypy-boto3-cloud9==0.1.7"],
        "cloud9-with-docs": ["mypy-boto3-cloud9-with-docs==0.1.7"],
        "clouddirectory": ["mypy-boto3-clouddirectory==0.1.7"],
        "clouddirectory-with-docs": ["mypy-boto3-clouddirectory-with-docs==0.1.7"],
        "cloudformation": ["mypy-boto3-cloudformation==0.1.7"],
        "cloudformation-with-docs": ["mypy-boto3-cloudformation-with-docs==0.1.7"],
        "cloudfront": ["mypy-boto3-cloudfront==0.1.7"],
        "cloudfront-with-docs": ["mypy-boto3-cloudfront-with-docs==0.1.7"],
        "cloudhsm": ["mypy-boto3-cloudhsm==0.1.7"],
        "cloudhsm-with-docs": ["mypy-boto3-cloudhsm-with-docs==0.1.7"],
        "cloudhsmv2": ["mypy-boto3-cloudhsmv2==0.1.7"],
        "cloudhsmv2-with-docs": ["mypy-boto3-cloudhsmv2-with-docs==0.1.7"],
        "cloudsearch": ["mypy-boto3-cloudsearch==0.1.7"],
        "cloudsearch-with-docs": ["mypy-boto3-cloudsearch-with-docs==0.1.7"],
        "cloudsearchdomain": ["mypy-boto3-cloudsearchdomain==0.1.7"],
        "cloudsearchdomain-with-docs": [
            "mypy-boto3-cloudsearchdomain-with-docs==0.1.7"
        ],
        "cloudtrail": ["mypy-boto3-cloudtrail==0.1.7"],
        "cloudtrail-with-docs": ["mypy-boto3-cloudtrail-with-docs==0.1.7"],
        "cloudwatch": ["mypy-boto3-cloudwatch==0.1.7"],
        "cloudwatch-with-docs": ["mypy-boto3-cloudwatch-with-docs==0.1.7"],
        "codebuild": ["mypy-boto3-codebuild==0.1.7"],
        "codebuild-with-docs": ["mypy-boto3-codebuild-with-docs==0.1.7"],
        "codecommit": ["mypy-boto3-codecommit==0.1.7"],
        "codecommit-with-docs": ["mypy-boto3-codecommit-with-docs==0.1.7"],
        "codedeploy": ["mypy-boto3-codedeploy==0.1.7"],
        "codedeploy-with-docs": ["mypy-boto3-codedeploy-with-docs==0.1.7"],
        "codepipeline": ["mypy-boto3-codepipeline==0.1.7"],
        "codepipeline-with-docs": ["mypy-boto3-codepipeline-with-docs==0.1.7"],
        "codestar": ["mypy-boto3-codestar==0.1.7"],
        "codestar-with-docs": ["mypy-boto3-codestar-with-docs==0.1.7"],
        "codestar-notifications": ["mypy-boto3-codestar-notifications==0.1.7"],
        "codestar-notifications-with-docs": [
            "mypy-boto3-codestar-notifications-with-docs==0.1.7"
        ],
        "cognito-identity": ["mypy-boto3-cognito-identity==0.1.7"],
        "cognito-identity-with-docs": ["mypy-boto3-cognito-identity-with-docs==0.1.7"],
        "cognito-idp": ["mypy-boto3-cognito-idp==0.1.7"],
        "cognito-idp-with-docs": ["mypy-boto3-cognito-idp-with-docs==0.1.7"],
        "cognito-sync": ["mypy-boto3-cognito-sync==0.1.7"],
        "cognito-sync-with-docs": ["mypy-boto3-cognito-sync-with-docs==0.1.7"],
        "comprehend": ["mypy-boto3-comprehend==0.1.7"],
        "comprehend-with-docs": ["mypy-boto3-comprehend-with-docs==0.1.7"],
        "comprehendmedical": ["mypy-boto3-comprehendmedical==0.1.7"],
        "comprehendmedical-with-docs": [
            "mypy-boto3-comprehendmedical-with-docs==0.1.7"
        ],
        "config": ["mypy-boto3-config==0.1.7"],
        "config-with-docs": ["mypy-boto3-config-with-docs==0.1.7"],
        "connect": ["mypy-boto3-connect==0.1.7"],
        "connect-with-docs": ["mypy-boto3-connect-with-docs==0.1.7"],
        "cur": ["mypy-boto3-cur==0.1.7"],
        "cur-with-docs": ["mypy-boto3-cur-with-docs==0.1.7"],
        "datapipeline": ["mypy-boto3-datapipeline==0.1.7"],
        "datapipeline-with-docs": ["mypy-boto3-datapipeline-with-docs==0.1.7"],
        "datasync": ["mypy-boto3-datasync==0.1.7"],
        "datasync-with-docs": ["mypy-boto3-datasync-with-docs==0.1.7"],
        "dax": ["mypy-boto3-dax==0.1.7"],
        "dax-with-docs": ["mypy-boto3-dax-with-docs==0.1.7"],
        "devicefarm": ["mypy-boto3-devicefarm==0.1.7"],
        "devicefarm-with-docs": ["mypy-boto3-devicefarm-with-docs==0.1.7"],
        "directconnect": ["mypy-boto3-directconnect==0.1.7"],
        "directconnect-with-docs": ["mypy-boto3-directconnect-with-docs==0.1.7"],
        "discovery": ["mypy-boto3-discovery==0.1.7"],
        "discovery-with-docs": ["mypy-boto3-discovery-with-docs==0.1.7"],
        "dlm": ["mypy-boto3-dlm==0.1.7"],
        "dlm-with-docs": ["mypy-boto3-dlm-with-docs==0.1.7"],
        "dms": ["mypy-boto3-dms==0.1.7"],
        "dms-with-docs": ["mypy-boto3-dms-with-docs==0.1.7"],
        "docdb": ["mypy-boto3-docdb==0.1.7"],
        "docdb-with-docs": ["mypy-boto3-docdb-with-docs==0.1.7"],
        "ds": ["mypy-boto3-ds==0.1.7"],
        "ds-with-docs": ["mypy-boto3-ds-with-docs==0.1.7"],
        "dynamodb": ["mypy-boto3-dynamodb==0.1.7"],
        "dynamodb-with-docs": ["mypy-boto3-dynamodb-with-docs==0.1.7"],
        "dynamodbstreams": ["mypy-boto3-dynamodbstreams==0.1.7"],
        "dynamodbstreams-with-docs": ["mypy-boto3-dynamodbstreams-with-docs==0.1.7"],
        "ec2": ["mypy-boto3-ec2==0.1.7"],
        "ec2-with-docs": ["mypy-boto3-ec2-with-docs==0.1.7"],
        "ec2-instance-connect": ["mypy-boto3-ec2-instance-connect==0.1.7"],
        "ec2-instance-connect-with-docs": [
            "mypy-boto3-ec2-instance-connect-with-docs==0.1.7"
        ],
        "ecr": ["mypy-boto3-ecr==0.1.7"],
        "ecr-with-docs": ["mypy-boto3-ecr-with-docs==0.1.7"],
        "ecs": ["mypy-boto3-ecs==0.1.7"],
        "ecs-with-docs": ["mypy-boto3-ecs-with-docs==0.1.7"],
        "efs": ["mypy-boto3-efs==0.1.7"],
        "efs-with-docs": ["mypy-boto3-efs-with-docs==0.1.7"],
        "eks": ["mypy-boto3-eks==0.1.7"],
        "eks-with-docs": ["mypy-boto3-eks-with-docs==0.1.7"],
        "elasticache": ["mypy-boto3-elasticache==0.1.7"],
        "elasticache-with-docs": ["mypy-boto3-elasticache-with-docs==0.1.7"],
        "elasticbeanstalk": ["mypy-boto3-elasticbeanstalk==0.1.7"],
        "elasticbeanstalk-with-docs": ["mypy-boto3-elasticbeanstalk-with-docs==0.1.7"],
        "elastictranscoder": ["mypy-boto3-elastictranscoder==0.1.7"],
        "elastictranscoder-with-docs": [
            "mypy-boto3-elastictranscoder-with-docs==0.1.7"
        ],
        "elb": ["mypy-boto3-elb==0.1.7"],
        "elb-with-docs": ["mypy-boto3-elb-with-docs==0.1.7"],
        "elbv2": ["mypy-boto3-elbv2==0.1.7"],
        "elbv2-with-docs": ["mypy-boto3-elbv2-with-docs==0.1.7"],
        "emr": ["mypy-boto3-emr==0.1.7"],
        "emr-with-docs": ["mypy-boto3-emr-with-docs==0.1.7"],
        "es": ["mypy-boto3-es==0.1.7"],
        "es-with-docs": ["mypy-boto3-es-with-docs==0.1.7"],
        "events": ["mypy-boto3-events==0.1.7"],
        "events-with-docs": ["mypy-boto3-events-with-docs==0.1.7"],
        "firehose": ["mypy-boto3-firehose==0.1.7"],
        "firehose-with-docs": ["mypy-boto3-firehose-with-docs==0.1.7"],
        "fms": ["mypy-boto3-fms==0.1.7"],
        "fms-with-docs": ["mypy-boto3-fms-with-docs==0.1.7"],
        "forecast": ["mypy-boto3-forecast==0.1.7"],
        "forecast-with-docs": ["mypy-boto3-forecast-with-docs==0.1.7"],
        "forecastquery": ["mypy-boto3-forecastquery==0.1.7"],
        "forecastquery-with-docs": ["mypy-boto3-forecastquery-with-docs==0.1.7"],
        "fsx": ["mypy-boto3-fsx==0.1.7"],
        "fsx-with-docs": ["mypy-boto3-fsx-with-docs==0.1.7"],
        "gamelift": ["mypy-boto3-gamelift==0.1.7"],
        "gamelift-with-docs": ["mypy-boto3-gamelift-with-docs==0.1.7"],
        "glacier": ["mypy-boto3-glacier==0.1.7"],
        "glacier-with-docs": ["mypy-boto3-glacier-with-docs==0.1.7"],
        "globalaccelerator": ["mypy-boto3-globalaccelerator==0.1.7"],
        "globalaccelerator-with-docs": [
            "mypy-boto3-globalaccelerator-with-docs==0.1.7"
        ],
        "glue": ["mypy-boto3-glue==0.1.7"],
        "glue-with-docs": ["mypy-boto3-glue-with-docs==0.1.7"],
        "greengrass": ["mypy-boto3-greengrass==0.1.7"],
        "greengrass-with-docs": ["mypy-boto3-greengrass-with-docs==0.1.7"],
        "groundstation": ["mypy-boto3-groundstation==0.1.7"],
        "groundstation-with-docs": ["mypy-boto3-groundstation-with-docs==0.1.7"],
        "guardduty": ["mypy-boto3-guardduty==0.1.7"],
        "guardduty-with-docs": ["mypy-boto3-guardduty-with-docs==0.1.7"],
        "health": ["mypy-boto3-health==0.1.7"],
        "health-with-docs": ["mypy-boto3-health-with-docs==0.1.7"],
        "iam": ["mypy-boto3-iam==0.1.7"],
        "iam-with-docs": ["mypy-boto3-iam-with-docs==0.1.7"],
        "importexport": ["mypy-boto3-importexport==0.1.7"],
        "importexport-with-docs": ["mypy-boto3-importexport-with-docs==0.1.7"],
        "inspector": ["mypy-boto3-inspector==0.1.7"],
        "inspector-with-docs": ["mypy-boto3-inspector-with-docs==0.1.7"],
        "iot": ["mypy-boto3-iot==0.1.7"],
        "iot-with-docs": ["mypy-boto3-iot-with-docs==0.1.7"],
        "iot-data": ["mypy-boto3-iot-data==0.1.7"],
        "iot-data-with-docs": ["mypy-boto3-iot-data-with-docs==0.1.7"],
        "iot-jobs-data": ["mypy-boto3-iot-jobs-data==0.1.7"],
        "iot-jobs-data-with-docs": ["mypy-boto3-iot-jobs-data-with-docs==0.1.7"],
        "iot1click-devices": ["mypy-boto3-iot1click-devices==0.1.7"],
        "iot1click-devices-with-docs": [
            "mypy-boto3-iot1click-devices-with-docs==0.1.7"
        ],
        "iot1click-projects": ["mypy-boto3-iot1click-projects==0.1.7"],
        "iot1click-projects-with-docs": [
            "mypy-boto3-iot1click-projects-with-docs==0.1.7"
        ],
        "iotanalytics": ["mypy-boto3-iotanalytics==0.1.7"],
        "iotanalytics-with-docs": ["mypy-boto3-iotanalytics-with-docs==0.1.7"],
        "iotevents": ["mypy-boto3-iotevents==0.1.7"],
        "iotevents-with-docs": ["mypy-boto3-iotevents-with-docs==0.1.7"],
        "iotevents-data": ["mypy-boto3-iotevents-data==0.1.7"],
        "iotevents-data-with-docs": ["mypy-boto3-iotevents-data-with-docs==0.1.7"],
        "iotthingsgraph": ["mypy-boto3-iotthingsgraph==0.1.7"],
        "iotthingsgraph-with-docs": ["mypy-boto3-iotthingsgraph-with-docs==0.1.7"],
        "kafka": ["mypy-boto3-kafka==0.1.7"],
        "kafka-with-docs": ["mypy-boto3-kafka-with-docs==0.1.7"],
        "kinesis": ["mypy-boto3-kinesis==0.1.7"],
        "kinesis-with-docs": ["mypy-boto3-kinesis-with-docs==0.1.7"],
        "kinesis-video-archived-media": [
            "mypy-boto3-kinesis-video-archived-media==0.1.7"
        ],
        "kinesis-video-archived-media-with-docs": [
            "mypy-boto3-kinesis-video-archived-media-with-docs==0.1.7"
        ],
        "kinesis-video-media": ["mypy-boto3-kinesis-video-media==0.1.7"],
        "kinesis-video-media-with-docs": [
            "mypy-boto3-kinesis-video-media-with-docs==0.1.7"
        ],
        "kinesisanalytics": ["mypy-boto3-kinesisanalytics==0.1.7"],
        "kinesisanalytics-with-docs": ["mypy-boto3-kinesisanalytics-with-docs==0.1.7"],
        "kinesisanalyticsv2": ["mypy-boto3-kinesisanalyticsv2==0.1.7"],
        "kinesisanalyticsv2-with-docs": [
            "mypy-boto3-kinesisanalyticsv2-with-docs==0.1.7"
        ],
        "kinesisvideo": ["mypy-boto3-kinesisvideo==0.1.7"],
        "kinesisvideo-with-docs": ["mypy-boto3-kinesisvideo-with-docs==0.1.7"],
        "kms": ["mypy-boto3-kms==0.1.7"],
        "kms-with-docs": ["mypy-boto3-kms-with-docs==0.1.7"],
        "lakeformation": ["mypy-boto3-lakeformation==0.1.7"],
        "lakeformation-with-docs": ["mypy-boto3-lakeformation-with-docs==0.1.7"],
        "lambda": ["mypy-boto3-lambda==0.1.7"],
        "lambda-with-docs": ["mypy-boto3-lambda-with-docs==0.1.7"],
        "lex-models": ["mypy-boto3-lex-models==0.1.7"],
        "lex-models-with-docs": ["mypy-boto3-lex-models-with-docs==0.1.7"],
        "lex-runtime": ["mypy-boto3-lex-runtime==0.1.7"],
        "lex-runtime-with-docs": ["mypy-boto3-lex-runtime-with-docs==0.1.7"],
        "license-manager": ["mypy-boto3-license-manager==0.1.7"],
        "license-manager-with-docs": ["mypy-boto3-license-manager-with-docs==0.1.7"],
        "lightsail": ["mypy-boto3-lightsail==0.1.7"],
        "lightsail-with-docs": ["mypy-boto3-lightsail-with-docs==0.1.7"],
        "logs": ["mypy-boto3-logs==0.1.7"],
        "logs-with-docs": ["mypy-boto3-logs-with-docs==0.1.7"],
        "machinelearning": ["mypy-boto3-machinelearning==0.1.7"],
        "machinelearning-with-docs": ["mypy-boto3-machinelearning-with-docs==0.1.7"],
        "macie": ["mypy-boto3-macie==0.1.7"],
        "macie-with-docs": ["mypy-boto3-macie-with-docs==0.1.7"],
        "managedblockchain": ["mypy-boto3-managedblockchain==0.1.7"],
        "managedblockchain-with-docs": [
            "mypy-boto3-managedblockchain-with-docs==0.1.7"
        ],
        "marketplace-entitlement": ["mypy-boto3-marketplace-entitlement==0.1.7"],
        "marketplace-entitlement-with-docs": [
            "mypy-boto3-marketplace-entitlement-with-docs==0.1.7"
        ],
        "marketplacecommerceanalytics": [
            "mypy-boto3-marketplacecommerceanalytics==0.1.7"
        ],
        "marketplacecommerceanalytics-with-docs": [
            "mypy-boto3-marketplacecommerceanalytics-with-docs==0.1.7"
        ],
        "mediaconnect": ["mypy-boto3-mediaconnect==0.1.7"],
        "mediaconnect-with-docs": ["mypy-boto3-mediaconnect-with-docs==0.1.7"],
        "mediaconvert": ["mypy-boto3-mediaconvert==0.1.7"],
        "mediaconvert-with-docs": ["mypy-boto3-mediaconvert-with-docs==0.1.7"],
        "medialive": ["mypy-boto3-medialive==0.1.7"],
        "medialive-with-docs": ["mypy-boto3-medialive-with-docs==0.1.7"],
        "mediapackage": ["mypy-boto3-mediapackage==0.1.7"],
        "mediapackage-with-docs": ["mypy-boto3-mediapackage-with-docs==0.1.7"],
        "mediapackage-vod": ["mypy-boto3-mediapackage-vod==0.1.7"],
        "mediapackage-vod-with-docs": ["mypy-boto3-mediapackage-vod-with-docs==0.1.7"],
        "mediastore": ["mypy-boto3-mediastore==0.1.7"],
        "mediastore-with-docs": ["mypy-boto3-mediastore-with-docs==0.1.7"],
        "mediastore-data": ["mypy-boto3-mediastore-data==0.1.7"],
        "mediastore-data-with-docs": ["mypy-boto3-mediastore-data-with-docs==0.1.7"],
        "mediatailor": ["mypy-boto3-mediatailor==0.1.7"],
        "mediatailor-with-docs": ["mypy-boto3-mediatailor-with-docs==0.1.7"],
        "meteringmarketplace": ["mypy-boto3-meteringmarketplace==0.1.7"],
        "meteringmarketplace-with-docs": [
            "mypy-boto3-meteringmarketplace-with-docs==0.1.7"
        ],
        "mgh": ["mypy-boto3-mgh==0.1.7"],
        "mgh-with-docs": ["mypy-boto3-mgh-with-docs==0.1.7"],
        "mobile": ["mypy-boto3-mobile==0.1.7"],
        "mobile-with-docs": ["mypy-boto3-mobile-with-docs==0.1.7"],
        "mq": ["mypy-boto3-mq==0.1.7"],
        "mq-with-docs": ["mypy-boto3-mq-with-docs==0.1.7"],
        "mturk": ["mypy-boto3-mturk==0.1.7"],
        "mturk-with-docs": ["mypy-boto3-mturk-with-docs==0.1.7"],
        "neptune": ["mypy-boto3-neptune==0.1.7"],
        "neptune-with-docs": ["mypy-boto3-neptune-with-docs==0.1.7"],
        "opsworks": ["mypy-boto3-opsworks==0.1.7"],
        "opsworks-with-docs": ["mypy-boto3-opsworks-with-docs==0.1.7"],
        "opsworkscm": ["mypy-boto3-opsworkscm==0.1.7"],
        "opsworkscm-with-docs": ["mypy-boto3-opsworkscm-with-docs==0.1.7"],
        "organizations": ["mypy-boto3-organizations==0.1.7"],
        "organizations-with-docs": ["mypy-boto3-organizations-with-docs==0.1.7"],
        "personalize": ["mypy-boto3-personalize==0.1.7"],
        "personalize-with-docs": ["mypy-boto3-personalize-with-docs==0.1.7"],
        "personalize-events": ["mypy-boto3-personalize-events==0.1.7"],
        "personalize-events-with-docs": [
            "mypy-boto3-personalize-events-with-docs==0.1.7"
        ],
        "personalize-runtime": ["mypy-boto3-personalize-runtime==0.1.7"],
        "personalize-runtime-with-docs": [
            "mypy-boto3-personalize-runtime-with-docs==0.1.7"
        ],
        "pi": ["mypy-boto3-pi==0.1.7"],
        "pi-with-docs": ["mypy-boto3-pi-with-docs==0.1.7"],
        "pinpoint": ["mypy-boto3-pinpoint==0.1.7"],
        "pinpoint-with-docs": ["mypy-boto3-pinpoint-with-docs==0.1.7"],
        "pinpoint-email": ["mypy-boto3-pinpoint-email==0.1.7"],
        "pinpoint-email-with-docs": ["mypy-boto3-pinpoint-email-with-docs==0.1.7"],
        "pinpoint-sms-voice": ["mypy-boto3-pinpoint-sms-voice==0.1.7"],
        "pinpoint-sms-voice-with-docs": [
            "mypy-boto3-pinpoint-sms-voice-with-docs==0.1.7"
        ],
        "polly": ["mypy-boto3-polly==0.1.7"],
        "polly-with-docs": ["mypy-boto3-polly-with-docs==0.1.7"],
        "pricing": ["mypy-boto3-pricing==0.1.7"],
        "pricing-with-docs": ["mypy-boto3-pricing-with-docs==0.1.7"],
        "qldb": ["mypy-boto3-qldb==0.1.7"],
        "qldb-with-docs": ["mypy-boto3-qldb-with-docs==0.1.7"],
        "qldb-session": ["mypy-boto3-qldb-session==0.1.7"],
        "qldb-session-with-docs": ["mypy-boto3-qldb-session-with-docs==0.1.7"],
        "quicksight": ["mypy-boto3-quicksight==0.1.7"],
        "quicksight-with-docs": ["mypy-boto3-quicksight-with-docs==0.1.7"],
        "ram": ["mypy-boto3-ram==0.1.7"],
        "ram-with-docs": ["mypy-boto3-ram-with-docs==0.1.7"],
        "rds": ["mypy-boto3-rds==0.1.7"],
        "rds-with-docs": ["mypy-boto3-rds-with-docs==0.1.7"],
        "rds-data": ["mypy-boto3-rds-data==0.1.7"],
        "rds-data-with-docs": ["mypy-boto3-rds-data-with-docs==0.1.7"],
        "redshift": ["mypy-boto3-redshift==0.1.7"],
        "redshift-with-docs": ["mypy-boto3-redshift-with-docs==0.1.7"],
        "rekognition": ["mypy-boto3-rekognition==0.1.7"],
        "rekognition-with-docs": ["mypy-boto3-rekognition-with-docs==0.1.7"],
        "resource-groups": ["mypy-boto3-resource-groups==0.1.7"],
        "resource-groups-with-docs": ["mypy-boto3-resource-groups-with-docs==0.1.7"],
        "resourcegroupstaggingapi": ["mypy-boto3-resourcegroupstaggingapi==0.1.7"],
        "resourcegroupstaggingapi-with-docs": [
            "mypy-boto3-resourcegroupstaggingapi-with-docs==0.1.7"
        ],
        "robomaker": ["mypy-boto3-robomaker==0.1.7"],
        "robomaker-with-docs": ["mypy-boto3-robomaker-with-docs==0.1.7"],
        "route53": ["mypy-boto3-route53==0.1.7"],
        "route53-with-docs": ["mypy-boto3-route53-with-docs==0.1.7"],
        "route53domains": ["mypy-boto3-route53domains==0.1.7"],
        "route53domains-with-docs": ["mypy-boto3-route53domains-with-docs==0.1.7"],
        "route53resolver": ["mypy-boto3-route53resolver==0.1.7"],
        "route53resolver-with-docs": ["mypy-boto3-route53resolver-with-docs==0.1.7"],
        "s3": ["mypy-boto3-s3==0.1.7"],
        "s3-with-docs": ["mypy-boto3-s3-with-docs==0.1.7"],
        "s3control": ["mypy-boto3-s3control==0.1.7"],
        "s3control-with-docs": ["mypy-boto3-s3control-with-docs==0.1.7"],
        "sagemaker": ["mypy-boto3-sagemaker==0.1.7"],
        "sagemaker-with-docs": ["mypy-boto3-sagemaker-with-docs==0.1.7"],
        "sagemaker-runtime": ["mypy-boto3-sagemaker-runtime==0.1.7"],
        "sagemaker-runtime-with-docs": [
            "mypy-boto3-sagemaker-runtime-with-docs==0.1.7"
        ],
        "savingsplans": ["mypy-boto3-savingsplans==0.1.7"],
        "savingsplans-with-docs": ["mypy-boto3-savingsplans-with-docs==0.1.7"],
        "sdb": ["mypy-boto3-sdb==0.1.7"],
        "sdb-with-docs": ["mypy-boto3-sdb-with-docs==0.1.7"],
        "secretsmanager": ["mypy-boto3-secretsmanager==0.1.7"],
        "secretsmanager-with-docs": ["mypy-boto3-secretsmanager-with-docs==0.1.7"],
        "securityhub": ["mypy-boto3-securityhub==0.1.7"],
        "securityhub-with-docs": ["mypy-boto3-securityhub-with-docs==0.1.7"],
        "serverlessrepo": ["mypy-boto3-serverlessrepo==0.1.7"],
        "serverlessrepo-with-docs": ["mypy-boto3-serverlessrepo-with-docs==0.1.7"],
        "service-quotas": ["mypy-boto3-service-quotas==0.1.7"],
        "service-quotas-with-docs": ["mypy-boto3-service-quotas-with-docs==0.1.7"],
        "servicecatalog": ["mypy-boto3-servicecatalog==0.1.7"],
        "servicecatalog-with-docs": ["mypy-boto3-servicecatalog-with-docs==0.1.7"],
        "servicediscovery": ["mypy-boto3-servicediscovery==0.1.7"],
        "servicediscovery-with-docs": ["mypy-boto3-servicediscovery-with-docs==0.1.7"],
        "ses": ["mypy-boto3-ses==0.1.7"],
        "ses-with-docs": ["mypy-boto3-ses-with-docs==0.1.7"],
        "shield": ["mypy-boto3-shield==0.1.7"],
        "shield-with-docs": ["mypy-boto3-shield-with-docs==0.1.7"],
        "signer": ["mypy-boto3-signer==0.1.7"],
        "signer-with-docs": ["mypy-boto3-signer-with-docs==0.1.7"],
        "sms": ["mypy-boto3-sms==0.1.7"],
        "sms-with-docs": ["mypy-boto3-sms-with-docs==0.1.7"],
        "sms-voice": ["mypy-boto3-sms-voice==0.1.7"],
        "sms-voice-with-docs": ["mypy-boto3-sms-voice-with-docs==0.1.7"],
        "snowball": ["mypy-boto3-snowball==0.1.7"],
        "snowball-with-docs": ["mypy-boto3-snowball-with-docs==0.1.7"],
        "sns": ["mypy-boto3-sns==0.1.7"],
        "sns-with-docs": ["mypy-boto3-sns-with-docs==0.1.7"],
        "sqs": ["mypy-boto3-sqs==0.1.7"],
        "sqs-with-docs": ["mypy-boto3-sqs-with-docs==0.1.7"],
        "ssm": ["mypy-boto3-ssm==0.1.7"],
        "ssm-with-docs": ["mypy-boto3-ssm-with-docs==0.1.7"],
        "stepfunctions": ["mypy-boto3-stepfunctions==0.1.7"],
        "stepfunctions-with-docs": ["mypy-boto3-stepfunctions-with-docs==0.1.7"],
        "storagegateway": ["mypy-boto3-storagegateway==0.1.7"],
        "storagegateway-with-docs": ["mypy-boto3-storagegateway-with-docs==0.1.7"],
        "sts": ["mypy-boto3-sts==0.1.7"],
        "sts-with-docs": ["mypy-boto3-sts-with-docs==0.1.7"],
        "support": ["mypy-boto3-support==0.1.7"],
        "support-with-docs": ["mypy-boto3-support-with-docs==0.1.7"],
        "swf": ["mypy-boto3-swf==0.1.7"],
        "swf-with-docs": ["mypy-boto3-swf-with-docs==0.1.7"],
        "textract": ["mypy-boto3-textract==0.1.7"],
        "textract-with-docs": ["mypy-boto3-textract-with-docs==0.1.7"],
        "transcribe": ["mypy-boto3-transcribe==0.1.7"],
        "transcribe-with-docs": ["mypy-boto3-transcribe-with-docs==0.1.7"],
        "transfer": ["mypy-boto3-transfer==0.1.7"],
        "transfer-with-docs": ["mypy-boto3-transfer-with-docs==0.1.7"],
        "translate": ["mypy-boto3-translate==0.1.7"],
        "translate-with-docs": ["mypy-boto3-translate-with-docs==0.1.7"],
        "waf": ["mypy-boto3-waf==0.1.7"],
        "waf-with-docs": ["mypy-boto3-waf-with-docs==0.1.7"],
        "waf-regional": ["mypy-boto3-waf-regional==0.1.7"],
        "waf-regional-with-docs": ["mypy-boto3-waf-regional-with-docs==0.1.7"],
        "workdocs": ["mypy-boto3-workdocs==0.1.7"],
        "workdocs-with-docs": ["mypy-boto3-workdocs-with-docs==0.1.7"],
        "worklink": ["mypy-boto3-worklink==0.1.7"],
        "worklink-with-docs": ["mypy-boto3-worklink-with-docs==0.1.7"],
        "workmail": ["mypy-boto3-workmail==0.1.7"],
        "workmail-with-docs": ["mypy-boto3-workmail-with-docs==0.1.7"],
        "workmailmessageflow": ["mypy-boto3-workmailmessageflow==0.1.7"],
        "workmailmessageflow-with-docs": [
            "mypy-boto3-workmailmessageflow-with-docs==0.1.7"
        ],
        "workspaces": ["mypy-boto3-workspaces==0.1.7"],
        "workspaces-with-docs": ["mypy-boto3-workspaces-with-docs==0.1.7"],
        "xray": ["mypy-boto3-xray==0.1.7"],
        "xray-with-docs": ["mypy-boto3-xray-with-docs==0.1.7"],
    },
    install_requires=["mypy", "boto3"],
    zip_safe=False,
)
